#! /usr/lib/veetest/veetest -r
(revision "B.00.00")
(date "Mon 09/Nov/1992")
(component 0 "ROOTCONTEXT"
 (name "Text Strings Example")
 (interface
 )
 (implementation
  (locked no)
  (trigMode rad)
  (nextID 15)
  (component 0 "NOTE"
   (name "Warranty Disclaimer")
   (interface
   )
   (implementation
    (component text 4 5
     This example is provided as an
     illustration "as is", and Hewlett-Packard
     Company makes no warranty of any kind
     with regard to this example.
    )
   )
   (views
    (icon
     (extent 181 0)
    )
    (detail
     (origin 592 99)
     (extent 397 82)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 1 "NOTE"
   (interface
   )
   (implementation
    (component text 4 5
     Combining several text
     strings into one string
     and into an array of
     strings.
    )
   )
   (views
    (icon
    )
    (detail
     (origin 351 100)
     (extent 218 81)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 2 "LITERALCONSTANT"
   (name "Text Constant")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Text")
     (lock name constraints)
    )
   )
   (implementation
    (component value Text
     (name "Text Constant")
     (datum "One, ")
    )
    (component autoTrigger off)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Text
     (name "CString")
     (datum "")
    )
   )
   (views
    (icon
     (origin 67 258)
     (extent 127 25)
    )
    (detail
     (origin 30 244)
     (extent 201 32)
    )
    (active detail)
   )
  )
  (component 3 "TEXTDISPLAY"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 742 229)
     (extent 217 43)
    )
    (active detail)
   )
  )
  (component 4 "TEXTDISPLAY"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 743 334)
     (extent 215 73)
    )
    (active detail)
   )
  )
  (component 5 "LITERALCONSTANT"
   (name "Text Constant")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Text")
     (lock name constraints)
    )
   )
   (implementation
    (component value Text
     (name "Text Constant")
     (datum "Three.")
    )
    (component autoTrigger off)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Text
     (name "CString")
     (datum "")
    )
   )
   (views
    (icon
     (extent 127 0)
    )
    (detail
     (origin 30 454)
     (extent 201 32)
    )
    (active detail)
   )
  )
  (component 6 "LITERALCONSTANT"
   (name "Text Constant")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Text")
     (lock name constraints)
    )
   )
   (implementation
    (component value Text
     (name "Text Constant")
     (datum "Two, ")
    )
    (component autoTrigger off)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Text
     (name "CString")
     (datum "")
    )
   )
   (views
    (icon
     (extent 127 0)
    )
    (detail
     (origin 30 344)
     (extent 201 32)
    )
    (active detail)
   )
  )
  (component 7 "ACCUMULATOR"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
     (tag "InData")
     (requires
      (shape "Scalar")
     )
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Data")
     (tag "accumData")
     (lock name constraints)
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (origin 525 208)
     (extent 110 25)
    )
    (detail
     (origin 779 481)
     (extent 183 38)
    )
    (active icon)
   )
  )
  (component 8 "COLLECTOR"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
     (tag "Data")
    )
    (input 2
     (type trigger)
     (name "XEQ")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Array")
     (tag "Array")
     (lock constraints)
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
    (component output1D YES)
   )
   (views
    (icon
     (origin 375 398)
     (extent 110 25)
    )
    (detail
     (origin 561 278)
     (extent 29 84)
    )
    (terminals on)
    (active detail)
   )
  )
  (component 9 "FORMULA"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (input 2
     (type data)
     (name "B")
     (optional yes)
    )
    (input 3
     (type data)
     (name "C")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr 1 "A+B+C")
   )
   (views
    (icon
     (origin 351 238)
     (extent 78 64)
     (iconImage "formula.icon")
    )
    (detail
     (origin 521 413)
     (extent 89 135)
    )
    (terminals on)
    (active detail)
   )
  )
  (component 10 "TEXTDISPLAY"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 742 459)
     (extent 217 43)
    )
    (active detail)
   )
  )
  (component 11 "VECTORCONCATENATOR"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data1")
     (optional yes)
    )
    (input 2
     (type data)
     (name "Data2")
     (optional yes)
    )
    (input 3
     (type data)
     (name "Data3")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Array")
     (tag "Array")
     (lock constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 441 608)
     (extent 118 25)
    )
    (detail
     (origin 489 593)
     (extent 62 134)
    )
    (terminals on)
    (active detail)
   )
  )
  (component 12 "TEXTDISPLAY"
   (name "AlphaNumeric")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 654 627)
     (extent 212 66)
    )
    (active detail)
   )
  )
  (component 13 "JUNCTION"
   (name "JCT")
   (interface
    (input 1
     (type data)
     (name "A")
     (lock name constraints)
     (optional yes)
    )
    (input 2
     (type data)
     (name "B")
     (lock name constraints)
     (optional yes)
    )
    (input 3
     (type data)
     (name "C")
     (lock name constraints)
     (optional yes)
    )
    (output 1
     (type data)
     (name "Data")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 327 283)
     (extent 46 34)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 14 "CONTEXT"
   (name "Press For")
   (interface
    (sequence in)
    (sequence out)
   )
   (implementation
    (locked no)
    (trigMode deg)
    (nextID 3)
    (component 0 "TOGGLE"
     (name "Info About")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type control)
       (name "Reset")
       (lock name constraints)
       (optional yes)
      )
      (output 1
       (type data)
       (lock name constraints)
      )
     )
     (implementation
      (component value Int32
       (name "Info About")
       (values range 0 1)
       (datum 0)
      )
      (component autoTrigger on)
      (component initializeAtPrerun off)
      (component initializeAtActivate off)
      (component initValue Int32
       (name "LongInt")
       (datum 0)
      )
     )
     (views
      (icon
       (origin 173 321)
       (extent 114 39)
       (format button)
      )
      (detail
       (origin 249 323)
       (extent 42 54)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 1 "IFTHENELSE"
     (name "!= 0")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "A")
       (optional yes)
      )
      (output 1
       (type data)
       (name "Then")
       (lock name constraints)
      )
      (output 2
       (type data)
       (name "Else")
       (lock name constraints)
      )
     )
     (implementation
      (component isLocked no)
      (component expr "a!=0")
     )
     (views
      (icon
       (origin 337 328)
       (extent 46 25)
      )
      (detail
       (origin 369 318)
       (extent 73 64)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "CONTEXT"
     (name "Info About...")
     (interface
      (sequence in)
      (sequence out)
     )
     (implementation
      (locked no)
      (trigMode deg)
      (nextID 2)
      (component 0 "NOTE"
       (name "NotePad")
       (interface
       )
       (implementation
        (component text 18 9
         PURPOSE: Illustrate several ways to combine text strings.
         
         USER INPUT REQUIRED: Press RUN to see the results displayed.
         
         EXPLANATION:  Three string constants are supplied as "One, ", "Two, ", and "Three."
                  Using the JCT to send each string in turn to the "Accumulator" allows the
                  strings to be collected into one string.  This is useful when you don't know
         		 how many strings will be combined.  An alternate way to create the combined
         		 string is to use a formula box to "add" the strings.  You need to have as many
         		 inputs as you have strings to be combined.
         
         		 If you wish to create an array of strings instead of one string, you can use
         		 a JCT and a collector.  The XEQ pin on the collector must be pinged when all of
         		 the inputs have arrived.  This is done by connecting the sequence pins of the 
         		 text constants in order and connecting the sequence out pin of the third constant
         		 to the XEQ pin.  An alternate way to collect an array when you know the number
         		 of strings is to use a concatenator.
         
        )
       )
       (views
        (icon
         (origin 411 408)
         (extent 78 25)
        )
        (detail
         (origin 26 202)
         (extent 848 437)
         (editing enabled)
        )
        (active icon)
       )
      )
      (component 1 "CONFIRM"
       (name "DONE")
       (interface
        (sequence in)
        (sequence out)
        (output 1
         (type data)
         (name "Go")
         (lock name constraints)
        )
       )
       (implementation
       )
       (views
        (icon
         (origin 420 469)
         (extent 58 37)
        )
        (detail
         (origin 466 633)
         (extent 79 34)
        )
        (terminals on)
        (active icon)
       )
      )
      (configuration
      )
      (ShowOnExecPanel
       (origin 55 78)
       (extent 866 542)
       (panel
        (origin 29 163)
        (extent 862 514)
        (widget 1 icon
         (title off)
         (origin 434 608)
         (extent 58 37)
        )
        (widget 0 detail
         (title off)
         (origin 42 175)
         (extent 825 420)
         (editing disabled)
        )
       )
      )
     )
     (views
      (icon
       (origin 397 408)
       (extent 127 25)
      )
      (detail
       (origin 17 160)
       (extent 866 520)
       (configuration
       )
       (stackingOrder 1 0)
      )
      (active icon)
     )
    )
    (configuration
     (connect D2:0 D0:1)
     (connect D0:1 D1:1)
     (connect D1:1 D2:0)
    )
   )
   (views
    (icon
     (origin 415 408)
     (extent 110 25)
    )
    (panel
     (origin 11 102)
     (extent 319 77)
     (widget 0 icon
      (title off)
      (origin 113 115)
      (extent 114 39)
      (format button)
     )
    )
    (detail
     (origin 4 115)
     (extent 912 591)
     (configuration
      (connect D2:0 D0:1
       (Point 460 435)
       (Point 460 690)
       (Point 20 690)
       (Point 20 340)
       (Point 170 340)
      )
      (connect D0:1 D1:1
       (Point 289 340)
       (Point 334 340)
      )
      (connect D1:1 D2:0
       (Point 385 330)
       (Point 400 330)
       (Point 400 120)
       (Point 460 120)
       (Point 460 405)
      )
     )
     (stackingOrder 0 1 2)
    )
    (active panel)
    (active panel)
   )
  )
  (configuration
   (connect D7:1 D3:1)
   (connect D8:1 D4:1)
   (connect D6:0 D5:0)
   (connect D2:0 D6:0)
   (connect D13:1 D7:1)
   (connect D13:1 D8:1)
   (connect D5:0 D8:2)
   (connect D2:1 D9:1)
   (connect D6:1 D9:2)
   (connect D5:1 D9:3)
   (connect D9:1 D10:1)
   (connect D2:1 D11:1)
   (connect D6:1 D11:2)
   (connect D5:1 D11:3)
   (connect D11:1 D12:1)
   (connect D2:1 D13:1)
   (connect D6:1 D13:2)
   (connect D5:1 D13:3)
  )
 )
 (views
  (detail
   (origin 0 62)
   (extent 980 643)
   (configuration
    (connect D7:1 D3:1
     (Point 637 220)
     (Point 670 220)
     (Point 670 250)
     (Point 739 250)
    )
    (connect D8:1 D4:1
     (Point 652 320)
     (Point 700 320)
     (Point 700 370)
     (Point 740 370)
    )
    (connect D6:0 D5:0
     (Point 130 378)
     (Point 130 423)
    )
    (connect D2:0 D6:0
     (Point 130 278)
     (Point 130 313)
    )
    (connect D13:1 D7:1
     (Point 375 300)
     (Point 490 300)
     (Point 490 220)
     (Point 522 220)
    )
    (connect D13:1 D8:1
     (Point 375 300)
     (Point 508 300)
    )
    (connect D5:0 D8:2
     (Point 130 488)
     (Point 130 510)
     (Point 290 510)
     (Point 290 340)
     (Point 508 340)
    )
    (connect D2:1 D9:1
     (Point 233 260)
     (Point 390 260)
     (Point 390 440)
     (Point 478 440)
    )
    (connect D6:1 D9:2
     (Point 233 360)
     (Point 280 360)
     (Point 280 480)
     (Point 478 480)
    )
    (connect D5:1 D9:3
     (Point 233 470)
     (Point 270 470)
     (Point 270 520)
     (Point 478 520)
    )
    (connect D9:1 D10:1
     (Point 682 480)
     (Point 739 480)
    )
    (connect D2:1 D11:1
     (Point 233 260)
     (Point 390 260)
     (Point 390 440)
     (Point 420 440)
     (Point 420 620)
     (Point 426 620)
    )
    (connect D6:1 D11:2
     (Point 233 360)
     (Point 280 360)
     (Point 280 480)
     (Point 410 480)
     (Point 410 660)
     (Point 426 660)
    )
    (connect D5:1 D11:3
     (Point 233 470)
     (Point 270 470)
     (Point 270 520)
     (Point 400 520)
     (Point 400 700)
     (Point 426 700)
    )
    (connect D11:1 D12:1
     (Point 613 660)
     (Point 651 660)
    )
    (connect D2:1 D13:1
     (Point 233 260)
     (Point 250 260)
     (Point 250 290)
     (Point 324 290)
    )
    (connect D6:1 D13:2
     (Point 233 360)
     (Point 250 360)
     (Point 250 300)
     (Point 324 300)
    )
    (connect D5:1 D13:3
     (Point 233 470)
     (Point 260 470)
     (Point 260 310)
     (Point 324 310)
    )
   )
   (stackingOrder 0 1 2 3 4 5 6 8 9 10
     11 12 13 7 14)
  )
  (active detail)
  (numberFormats
   (realFormat standard)
   (realSigDigits 4)
   (realRadixSpec 4)
   (integerBase decimal)
  )
  (waveformSettings
   (timeSpan 0.02)
   (numPoints 256)
  )
 )
)
